Contributing Guidelines
=======================

Please see the `CONTRIBUTING.md <https://github.com/saint2706/Games/blob/master/CONTRIBUTING.md>`_ file in the repository root for complete contribution guidelines.

Quick Links
-----------

* `GitHub Repository <https://github.com/saint2706/Games>`_
* `Issue Tracker <https://github.com/saint2706/Games/issues>`_
* `Pull Requests <https://github.com/saint2706/Games/pulls>`_

Overview
--------

We welcome contributions of all kinds:

* Bug fixes
* New games
* Features for existing games
* Documentation improvements
* Test coverage
* Performance optimizations

Getting Started
---------------

1. Fork the repository
2. Clone your fork
3. Create a feature branch
4. Make your changes
5. Run tests
6. Submit a pull request

For detailed instructions, see the CONTRIBUTING.md file.
